Sybase — SQLAlchemy 1.4 Documentation

Release: 1.4.21 | Release Date: July 14, 2021

# SQLAlchemy 1.4 Documentation

# Sybase

Support for the Sybase database.

The following table summarizes current support levels for database release versions.

## DBAPI Support

The following dialect/DBAPI options are available. Please refer to individual DBAPI sections for connect information.

- Python-Sybase

- PyODBC

- mxODBC

Note

The Sybase dialect within SQLAlchemy is not currently supported. It is not tested within continuous integration and is likely to have many issues and caveats not currently handled. Consider using the external dialect instead.

Deprecated since version 1.4: The internal Sybase dialect is deprecated and will be removed in a future version. Use the external dialect.

## python-sybase

Support for the Sybase database via the Python-Sybase driver.

### DBAPI

Documentation and download information (if applicable) for Python-Sybase is available at: https://python-sybase.sourceforge.net/

### Connecting

Connect String:

    sybase+pysybase://<username>:<password>@<dsn>/[database name]

### Unicode Support

The python-sybase driver does not appear to support non-ASCII strings of any kind at this time.

## pyodbc

Support for the Sybase database via the PyODBC driver.

### DBAPI

Documentation and download information (if applicable) for PyODBC is available at: https://pypi.org/project/pyodbc/

### Connecting

Connect String:

    sybase+pyodbc://<username>:<password>@<dsnname>[/<database>]

### Unicode Support

The pyodbc driver currently supports usage of these Sybase types with Unicode or multibyte strings:

    CHAR
    NCHAR
    NVARCHAR
    TEXT
    VARCHAR

Currently not supported are:

    UNICHAR
    UNITEXT
    UNIVARCHAR

## mxodbc

Support for the Sybase database via the mxODBC driver.

### DBAPI

Documentation and download information (if applicable) for mxODBC is available at: https://www.egenix.com/

### Connecting

Connect String:

    sybase+mxodbc://<username>:<password>@<dsnname>

Note

This dialect is a stub only and is likely non functional at this time.